diff --git a/src/backend/replication/basebackup.c b/src/backend/replication/basebackup.c
index 4841095d17678bba146d7e577402ebd5edc53b4b..20d4ce36d88fbd9a2ec1f738779998ae7eac5db4 100644
--- a/src/backend/replication/basebackup.c
+++ b/src/backend/replication/basebackup.c
@@ -583,8 +583,9 @@ sendDir(char *path, int basepathlen, bool sizeonly)
 
 		snprintf(pathbuf, MAXPGPATH, "%s/%s", path, de->d_name);
 
-		/* Skip postmaster.pid in the data directory */
-		if (strcmp(pathbuf, "./postmaster.pid") == 0)
+		/* Skip postmaster.pid and postmaster.opts in the data directory */
+		if (strcmp(pathbuf, "./postmaster.pid") == 0 ||
+			strcmp(pathbuf, "./postmaster.opts") == 0)
 			continue;
 
 		if (lstat(pathbuf, &statbuf) != 0)